@@ -361,7 +361,7 @@ cherokee_buffer_drop_endding (cherokee_buffer_t *buffer, int num_chars)
 {
 	int num;
 
-	if (buffer->buf == NULL) {
+	if ((buffer->buf == NULL) || (num_chars <= 0)) {
 		return ret_ok;
 	}
 
@@ -569,40 +569,47 @@ ret_t
 cherokee_buffer_print_debug (cherokee_buffer_t *buf, int len)
 {
 	int           i, length;
-	char          text[17];
+	char          text[67];
+	char*         hex_text;
+	char*         ascii_text;
 	unsigned char tmp;
-
+	 
 	if ((len == -1) || (buf->len <= len)) {
 		length = buf->len;
 	} else {
 		length = len;
 	}
-
-	text [16] = 0;
+	 
+	if (length <= 0)
+		return ret_ok;
+	
+	memset(text, 0, 67);
 	for (i=0; i < length; i++) {
 		if (i%16 == 0) {
-			printf ("%08x ", i);
+			if (text[0] != 0){
+				printf ("%s%s", text, CRLF);
+			}
+			sprintf (text, "%08x%57c", i, ' ');
+			hex_text = text + 9;
+			ascii_text = text + 49;
 		}
-
+		 
 		tmp = buf->buf[i];
-		printf ("%02x",  tmp & 0xFF);
-
-		if ((tmp > ' ') &&  (tmp < 128))
-			text [i%16] = tmp;
-		else
-			text [i%16] = '.';
-
+		sprintf (hex_text, "%02x",  tmp & 0xFF);
+		hex_text += 2;
+		*hex_text = ' ';
 		if ((i+1)%2 == 0) {
-			printf (" ");
+			hex_text++;
 		}
-
-		if ((i+1)%16 == 0) {
-			printf ("%s\n", text);
-		}
-
-		fflush(stdout);
+		 
+		if ((tmp > ' ') &&  (tmp < 128))
+			*ascii_text = tmp;
+		else
+			*ascii_text = '.';
+		ascii_text += 1;
 	}
-	printf (CRLF);
+	printf ("%s%s", text, CRLF);
+	fflush(stdout);
 
 	return ret_ok;
 }
@@ -795,19 +802,17 @@ cherokee_buffer_encode_base64 (cherokee_buffer_t *buf)
 ret_t 
 cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t **maybe_new)
 {
-	int i, j;
-	int extra = 0;
-	ret_t ret;
+	ret_t   ret;
+	cuint_t i;
+	cuint_t j;
+	cuint_t extra = 0;
 
 	/* Count extra characters
 	 */
 	for (i=0; i<buf->len; i++) {
-		if ((buf->buf[i] == '<') ||
-		    (buf->buf[i] == '>')) 
-		{
+		if ((buf->buf[i] == '<') || (buf->buf[i] == '>')) {
 			extra += 3;
-		} else 	if (buf->buf[i] == '&') 
-		{
+		} else 	if (buf->buf[i] == '&') {
 			extra += 4;
 		}
 	}
@@ -819,10 +824,10 @@ cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t **maybe_n
 	ret = cherokee_buffer_new (maybe_new);
 	if (unlikely(ret != ret_ok)) return ret;
 
-	ret = cherokee_buffer_add_buffer (*maybe_new, buf);
+	ret = cherokee_buffer_ensure_size (*maybe_new, buf->len + extra + 1);
 	if (unlikely(ret != ret_ok)) return ret;
 
-	ret = cherokee_buffer_ensure_size (*maybe_new, buf->len + extra);
+	ret = cherokee_buffer_add_buffer (*maybe_new, buf);
 	if (unlikely(ret != ret_ok)) return ret;
 
 	buf = *maybe_new;
