@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001, 2002, 2003, 2004, 2005 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2006 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -30,9 +30,11 @@
 #include "handler_redir.h"
 #include "module_loader.h"
 
-cherokee_module_info_t MODULE_INFO(error_redir) = {
-	   cherokee_handler,                 /* type     */
-	   cherokee_handler_error_redir_new  /* new func */
+
+cherokee_module_info_handler_t MODULE_INFO(error_redir) = {
+	.module.type     = cherokee_handler,                 /* type         */
+	.module.new_func = cherokee_handler_error_redir_new, /* new func     */
+	.valid_methods   = http_all_methods                  /* http methods */
 };
 
 
