@@ -76,12 +76,17 @@ cherokee_handler_file_new  (cherokee_handler_t **hdl, cherokee_connection_t *cnt
 	n->mime           = NULL;
 	n->using_sendfile = false;
 	n->info           = NULL;
-	n->nocache        = false;
+
+#ifdef CHEROKEE_EMBEDDED
+	n->use_cache      = true;
+#else
+	n->use_cache      = false;
+#endif
 
 	/* Check some properties
 	 */
 	if (properties != NULL) {
-		cherokee_typed_table_get_int (properties, "cache", &n->nocache);
+		cherokee_typed_table_get_int (properties, "cache", &n->use_cache);
 	}
 
 	/* Return the object
@@ -115,12 +120,12 @@ check_cached (cherokee_handler_file_t *n)
 {
 	ret_t                  ret;
 	char                  *header;
-	int                    header_len;
+	cuint_t                header_len;
 	cherokee_connection_t *conn = HANDLER_CONN(n);
 
 	/* Based in time
 	 */
-	ret = cherokee_header_get_unknown (conn->header, "If-Modified-Since", 17, &header, &header_len);
+	ret = cherokee_header_get_known (&conn->header, header_if_modified_since, &header, &header_len);
 	if (ret == ret_ok)  {
 		time_t req_time;
 		char   tmp;
@@ -152,12 +157,12 @@ check_cached (cherokee_handler_file_t *n)
 	
 	/* HTTP/1.1 only headers
 	 */
-	if (conn->header->version < http_version_11)
+	if (conn->header.version < http_version_11)
 		return ret_ok;
 
 	/* Based in ETag
 	 */
-	ret = cherokee_header_get_unknown (conn->header, "If-None-Match", 13, &header, &header_len);
+	ret = cherokee_header_get_known (&conn->header, header_if_none_match, &header, &header_len);
 	if (ret == ret_ok)  {
 		int    tmp_len;
 		CHEROKEE_TEMP(tmp,100);
@@ -172,7 +177,7 @@ check_cached (cherokee_handler_file_t *n)
 	
 	/* If-Range
 	 */
-	ret = cherokee_header_get_unknown (conn->header, "If-Range", 8, &header, &header_len);
+	ret = cherokee_header_get_known (&conn->header, header_if_range, &header, &header_len);
 	if (ret == ret_ok)  {
 		time_t req_time;
 		char   tmp;
@@ -252,8 +257,8 @@ stat_local_directory (cherokee_handler_file_t *n, cherokee_connection_t *conn, c
 
 	/* Without cache
 	 */
-	if (n->nocache) {
-		re = stat (conn->local_directory.buf, &n->nocache_info);
+	if (! n->use_cache) {
+		re = stat (conn->local_directory.buf, &n->cache_info);
 		if (re < 0) {
 			switch (errno) {
 			case ENOENT: 
@@ -270,12 +275,13 @@ stat_local_directory (cherokee_handler_file_t *n, cherokee_connection_t *conn, c
 			return ret_error;
 		}
 
-		*info = &n->nocache_info;		
+		*info = &n->cache_info;		
 		return ret_ok;
 	} 
 
 	/* I/O cache
 	 */
+#ifndef CHEROKEE_EMBEDDED
 	ret = cherokee_iocache_stat_get (srv->iocache, conn->local_directory.buf, io_entry);
 	if (ret != ret_ok) {
 		switch (ret) {
@@ -295,6 +301,9 @@ stat_local_directory (cherokee_handler_file_t *n, cherokee_connection_t *conn, c
 
 	*info = &(*io_entry)->state;
 	return ret_ok;
+#endif 
+
+	return ret_error;
 }
 
 
@@ -338,11 +347,11 @@ cherokee_handler_file_init (cherokee_handler_file_t *n)
 	/* Is this file cached in the io cache?
 	 */
 #ifndef CHEROKEE_EMBEDDED
-	use_io = ((!n->nocache) &&
+	use_io = ((!n->use_cache) &&
 		  (conn->encoder == NULL) &&
-		  (conn->socket->is_tls == non_TLS) &&
+		  (conn->socket.is_tls == non_TLS) &&
 		  (n->info->st_size <= IOCACHE_MAX_FILE_SIZE) &&
-		  (http_method_with_body (conn->header->method)));
+		  (http_method_with_body (conn->header.method)));
 	
 	if (use_io) {
 		ret = cherokee_iocache_mmap_lookup (srv->iocache,
@@ -445,7 +454,7 @@ cherokee_handler_file_init (cherokee_handler_file_t *n)
 			     (conn->encoder == NULL) &&
 			     (n->info->st_size >= srv->sendfile.min) && 
 			     (n->info->st_size <  srv->sendfile.max) &&
-			     (conn->socket->is_tls == non_TLS));
+			     (conn->socket.is_tls == non_TLS));
 
 # ifdef HAVE_SENDFILE_BROKEN
 	n->using_sendfile = false;
@@ -473,7 +482,7 @@ cherokee_handler_file_step (cherokee_handler_file_t *fhdl,
 		ret_t   ret;
 		ssize_t sent;
 		
-		ret = cherokee_socket_sendfile (conn->socket,                      /* cherokee_socket_t *socket */
+		ret = cherokee_socket_sendfile (&conn->socket,                     /* cherokee_socket_t *socket */
 						fhdl->fd,                          /* int                fd     */
 						conn->range_end - fhdl->offset,    /* size_t             size   */
 						&fhdl->offset,                     /* off_t             *offset */
@@ -583,9 +592,9 @@ cherokee_handler_file_add_headers (cherokee_handler_file_t *fhdl,
 		cuint_t            maxage;
 
 		cherokee_mime_entry_get_type (fhdl->mime, &mime);
-		cherokee_buffer_add (buffer, "Content-Type: ", 14);
+		cherokee_buffer_add_str (buffer, "Content-Type: ");
 		cherokee_buffer_add_buffer (buffer, mime);
-		cherokee_buffer_add (buffer, CRLF, 2);
+		cherokee_buffer_add_str (buffer, CRLF);
 
 		ret = cherokee_mime_entry_get_maxage (fhdl->mime, &maxage);		
 		if (ret == ret_ok) {
@@ -596,7 +605,7 @@ cherokee_handler_file_add_headers (cherokee_handler_file_t *fhdl,
 
 	/* Etag
 	 */
-	if (HANDLER_CONN(fhdl)->header->version >= http_version_11) { 
+	if (HANDLER_CONN(fhdl)->header.version >= http_version_11) { 
 		cherokee_buffer_add_va (buffer, "Etag: %lx=%lx"CRLF, fhdl->info->st_mtime, fhdl->info->st_size);
 	}
 
