@@ -36,7 +36,7 @@ typedef struct {
 } item_t;
 
 
-static inline int
+static int
 equal (const void *avl_a, const void *avl_b, void *avl_param)
 {
 	avl_param = avl_param;
@@ -44,6 +44,14 @@ equal (const void *avl_a, const void *avl_b, void *avl_param)
 	return strcmp(((item_t *)avl_a)->key, ((item_t *)avl_b)->key);
 }
 
+static int
+equal_case (const void *avl_a, const void *avl_b, void *avl_param)
+{
+	avl_param = avl_param;
+
+	return strcasecmp(((item_t *)avl_a)->key, ((item_t *)avl_b)->key);
+}
+
 
 static inline void
 del_item (void *avl_item, void *avl_param)
@@ -80,6 +88,18 @@ cherokee_table_init (cherokee_table_t *tab)
 }
 
 
+ret_t
+cherokee_table_init_case (cherokee_table_t *tab)
+{
+	tab->tree = avl_create (equal_case, NULL, NULL);
+	if (tab->tree == NULL) {
+		return ret_error;
+	}
+
+	return ret_ok;
+}
+
+
 ret_t
 cherokee_table_free (cherokee_table_t *tab)
 {
