@@ -1,5 +1,13 @@
 #!/usr/bin/env python
 
+# Cherokee QA Tests
+#
+# Authors:
+#      Alvaro Lopez Ortega <alvaro@alobbs.com>
+#
+# Copyright (C) 2001-2006 Alvaro Lopez Ortega
+# This file is distributed under the GPL license.
+
 import os
 import sys
 import time
@@ -16,8 +24,8 @@ from conf import *
 # Configuration parameters
 num      = 1
 thds     = 1
+pause    = 0
 ssl      = False
-pause    = False
 clean    = True
 kill     = True
 quiet    = False
@@ -26,6 +34,7 @@ strace   = False
 port     = None
 method   = None
 nobody   = False
+fcgi     = True
 
 server   = CHEROKEE_PATH
 
@@ -34,6 +43,8 @@ www = tempfile.mkdtemp ("cherokee_www")
 tmp = www + "/_tmp/"
 os.makedirs (tmp)
 
+map (lambda x: os.chmod (x, 0777), [www, tmp])
+
 # Make the files list
 files = []
 param = []
@@ -52,9 +63,9 @@ if len(files) == 0:
 
 # Process the parameters
 for p in param:
-    if   p     == '-d': pause    = True
-    elif p     == '-c': clean    = False
+    if   p     == '-c': clean    = False
     elif p     == '-k': kill     = False
+    elif p     == '-f': fcgi     = False    
     elif p     == '-q': quiet    = True
     elif p     == '-v': valgrind = True
     elif p     == '-s': ssl      = True
@@ -63,9 +74,17 @@ for p in param:
     elif p[:2] == '-n': num      = int(p[2:])
     elif p[:2] == '-t': thds     = int(p[2:])
     elif p[:2] == '-p': port     = int(p[2:])
+    elif p[:2] == '-d': pause    = p[2:]
     elif p[:2] == '-m': method   = p[2:]
     elif p[:2] == '-e': server   = p[2:]
 
+# Fix up pause
+if type(pause) == types.StringType:
+    if len(pause) > 0:
+        pause = int(pause)
+    else:
+        pause = sys.maxint
+
 # Configuration file base
 CONF_BASE = """# Cherokee QA tests
                Port %d
@@ -76,9 +95,20 @@ CONF_BASE = """# Cherokee QA tests
                Directory / { Handler common }
                DirectoryIndex test_index.html, test_index.php, /super_test_index.php
                Encoder gzip { allow txt }
+               MimeFile /etc/cherokee/mime.types
             """ % (PORT, www)
 
-BOTTON_CONF = "Extension php { Handler phpcgi { Interpreter %s } }" % (PHPCGI_PATH)
+if fcgi:
+    PHP_EXTENSION = """Extension php {
+                      Handler fcgi {
+                         Server localhost:%d {
+                           Env PHP_FCGI_CHILDREN "5"
+                           Interpreter "%s -b %d"
+                         }
+                      }
+                  }""" % (PHP_FCGI_PORT, PHPCGI_PATH, PHP_FCGI_PORT)
+else:
+    PHP_EXTENSION = "Extension php { Handler phpcgi { Interpreter %s } }" % (PHPCGI_PATH)
 
 
 if ssl:
@@ -103,8 +133,9 @@ for m in mods:
     obj = m.Test()
     # Update 'base.py': TestCollection if new
     # properties are added here!
-    obj.tmp    = tmp
-    obj.nobody = nobody
+    obj.tmp      = tmp
+    obj.nobody   = nobody
+    obj.php_conf = PHP_EXTENSION
     objs.append(obj)
 
 # Prepare www files
@@ -118,7 +149,7 @@ for obj in objs:
         mod_conf += obj.conf+"\n"
 
 # Write down the configuration file
-cfg = CONF_BASE + mod_conf + BOTTON_CONF
+cfg = CONF_BASE + mod_conf + PHP_EXTENSION
 cfg_file = tempfile.mktemp("cherokee_tmp_cfg")
 cfg_fd = open (cfg_file, 'w')
 cfg_fd.write (cfg)
@@ -165,6 +196,7 @@ def clean_up():
 
 def mainloop_iterator(objs):
     global port
+    global pause
     global its_clean
 
     time.sleep (.2)
@@ -173,17 +205,19 @@ def mainloop_iterator(objs):
         for obj in objs:
             go_ahead = obj.Precondition()
 
-            if go_ahead and pause:
+            if go_ahead and pause > 0:
                 print "Press <Enter> to continue.."
                 sys.stdin.readline()
+                pause = pause - 1
 
             if not quiet:
                 if ssl: print "SSL:",
                 print "%s: " % (obj.name) + " "*(40 - len(obj.name)),
                 sys.stdout.flush()
 
-            if not go_ahead and not quiet:
-                print "Skipped"
+            if not go_ahead:
+                if not quiet:
+                    print "Skipped"
                 continue
     
             if port is None:
